@@ -6,7 +6,7 @@ require 5.006 ;
 use strict ;
 use warnings;
 
-use IO::Compress::Base::Common 2.059 ;
+use IO::Compress::Base::Common 2.066 ;
 
 use IO::File (); ;
 use Scalar::Util ();
@@ -20,7 +20,7 @@ use Symbol();
 our (@ISA, $VERSION);
 @ISA    = qw(Exporter IO::File);
 
-$VERSION = '2.059';
+$VERSION = '2.066';
 
 #Can't locate object method "SWASHNEW" via package "utf8" (perhaps you forgot to load "utf8"?) at .../ext/Compress-Zlib/Gzip/blib/lib/Compress/Zlib/Common.pm line 16.
 
@@ -265,7 +265,7 @@ sub _create
             if ($outType eq 'handle') {
                 *$obj->{FH} = $outValue ;
                 setBinModeOutput(*$obj->{FH}) ;
-                $outValue->flush() ;
+                #$outValue->flush() ;
                 *$obj->{Handle} = 1 ;
                 if ($appendOutput)
                 {
@@ -684,10 +684,8 @@ sub printf
     defined $self->syswrite(sprintf($fmt, @_));
 }
 
-
-
-sub flush
-{   
+sub _flushCompressed
+{
     my $self = shift ;
 
     my $outBuffer='';
@@ -704,6 +702,15 @@ sub flush
 
     $self->outputPayload($outBuffer)
         or return 0;
+    return 1;        
+}
+
+sub flush
+{   
+    my $self = shift ;
+
+    $self->_flushCompressed(@_)
+        or return 0;        
 
     if ( defined *$self->{FH} ) {
         defined *$self->{FH}->flush()
@@ -830,7 +837,6 @@ sub close
 
     if (defined *$self->{FH}) {
 
-        #if (! *$self->{Handle} || *$self->{AutoClose}) {
         if ((! *$self->{Handle} || *$self->{AutoClose}) && ! *$self->{StdIO}) {
             $! = 0 ;
             *$self->{FH}->close()
@@ -1013,7 +1019,7 @@ IO::Compress::Base - Base Class for IO::Compress modules
 =head1 DESCRIPTION
 
 This module is not intended for direct use in application code. Its sole
-purpose if to to be sub-classed by IO::Compress modules.
+purpose is to be sub-classed by IO::Compress modules.
 
 =head1 SEE ALSO
 
@@ -1035,7 +1041,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2012 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2014 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
